==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/vi-VN/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Xác nhận Hàng loạt Xóa Tài sản',
    'bulk_restore'      => 'Xác nhận khôi phục hàng loạt tài sản', 
  'bulk_delete_help'	=> 'Xem lại tài sản để xóa hàng loạt dưới đây. Sau khi đã xóa, những nội dung này có thể được khôi phục, nhưng chúng sẽ không còn được kết hợp với bất kỳ người dùng nào hiện đang được chỉ định.',
  'bulk_restore_help'	=> 'Hãy xem lại các tài sản cần khôi phục hàng loạt bên dưới. Sau khi được khôi phục, những tài sản này sẽ không được liên kết với bất kỳ người dùng nào mà chúng đã được chỉ định trước đó.',
  'bulk_delete_warn'	=> 'Bạn sắp xóa: asset_count tài sản.',
  'bulk_restore_warn'	=> 'Bạn sắp khôi phục :asset_count nội dung.',
    'bulk_update'		=> 'Cập nhật tài sản số lượng lớn',
    'bulk_update_help'	=> 'Form này cho phép bạn cập nhật nhiều tài sản cùng lúc. Chỉ điền vào ô bạn cần thay đổi. Bất kỳ ô nào để trống sẽ thông báo là chưa thay đổi. ',
    'bulk_update_warn'	=> 'Bạn sắp chỉnh sửa thuộc tính của một tài sản.|Bạn sắp chỉnh sửa thuộc tính của :asset_count tài sản.',
    'bulk_update_with_custom_field' => 'Lưu ý tài sản là :asset_model_count các loại model khác nhau.',
    'bulk_update_model_prefix' => 'Trên những model', 
    'bulk_update_custom_field_unique' => 'Đây là trường thông tin duy nhất và không thể chỉnh sửa hàng loạt.',
    'checkedout_to'		=> 'Checkout đến',
    'checkout_date'		=> 'Ngày Checkout',
    'checkin_date'		=> 'Ngày Checkin',
    'checkout_to'		=> 'Checkout đến',
    'cost'				=> 'Chi phí mua hàng',
    'create'			=> 'Tạo tài sản',
    'date'				=> 'Ngày mua',
    'depreciation'	    => 'Khấu hao',
    'depreciates_on'	=> 'Trích khấu hao',
    'default_location'	=> 'Vị trí mặc định',
    'default_location_phone' => 'Số điện thoại mặc định',
    'eol_date'			=> 'Ngày EOL',
    'eol_rate'			=> 'Tỷ lệ EOL',
    'expected_checkin'  => 'Ngày mong muốn Checkin',
    'expires'			=> 'Hết hạn',
    'fully_depreciated'	=> 'Khấu hao hết',
    'help_checkout'		=> 'Nếu bạn muốn cấp phát tài sản này ngay lập tức, lựa chọn "Sẵn sàng để cấp phát" từ danh sách tình trạng bên trên. ',
    'mac_address'		=> 'Địa chỉ MAC',
    'manufacturer'		=> 'Nhà sản xuất',
    'model'				=> 'Kiểu tài sản',
    'months'			=> 'tháng',
    'name'				=> 'Tên tài sản',
    'notes'				=> 'Ghi chú',
    'order'				=> 'Số đơn hàng',
    'qr'				=> 'Mã QR',
    'requestable'		=> 'Những người dùng có thể yêu cầu tài sản này',
    'redirect_to_all'   => 'Return to all :type',
    'redirect_to_type'   => 'Go to :type',
    'redirect_to_checked_out_to'   => 'Go to Checked Out to',
    'select_statustype'	=> 'Lựa chọn loại tình trạng',
    'serial'			=> 'Số Sê-ri',
    'status'			=> 'Tình trạng',
    'tag'				=> 'Thẻ tài sản',
    'update'			=> 'Cập nhật tài sản',
    'warranty'			=> 'Bảo hành',
        'warranty_expires'		=> 'Hết hạn bảo hành',
    'years'				=> 'năm',
    'asset_location' => 'Cập nhật vị trí tài sản',
    'asset_location_update_default_current' => 'Cập nhật vị trí tài sản mặc định VÀ vị trí thực tế',
    'asset_location_update_default' => 'Chỉ cập nhật vị trí tài sản mặc định',
    'asset_location_update_actual' => 'Chỉ cập nhật vị trí thực tế',
    'asset_not_deployable' => 'Trạng thái tài sản là không cho phép cấp phát. Tài sản này không thể bàn giao.',
    'asset_deployable' => 'Trạng thái tài sản là được phép cấp phát. Tài sản này có thể bàn giao.',
    'processing_spinner' => 'Đang xử lý... (Quá trình này có thể mất một chút thời gian đối với các tệp lớn)',
    'optional_infos'  => 'Thông tin bổ sung',
    'order_details'   => 'Thông tin đơn hàng'
];

==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/vi-VN/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Xác nhận Hàng loạt Xóa Tài sản',
    'bulk_restore'      => 'Xác nhận khôi phục hàng loạt tài sản', 
  'bulk_delete_help'	=> 'Xem lại tài sản để xóa hàng loạt dưới đây. Sau khi đã xóa, những nội dung này có thể được khôi phục, nhưng chúng sẽ không còn được kết hợp với bất kỳ người dùng nào hiện đang được chỉ định.',
  'bulk_restore_help'	=> 'Hãy xem lại các tài sản cần khôi phục hàng loạt bên dưới. Sau khi được khôi phục, những tài sản này sẽ không được liên kết với bất kỳ người dùng nào mà chúng đã được chỉ định trước đó.',
  'bulk_delete_warn'	=> 'Bạn sắp xóa: asset_count tài sản.',
  'bulk_restore_warn'	=> 'Bạn sắp khôi phục :asset_count nội dung.',
    'bulk_update'		=> 'Cập nhật tài sản số lượng lớn',
    'bulk_update_help'	=> 'Form này cho phép bạn cập nhật nhiều tài sản cùng lúc. Chỉ điền vào ô bạn cần thay đổi. Bất kỳ ô nào để trống sẽ thông báo là chưa thay đổi. ',
    'bulk_update_warn'	=> 'Bạn sắp chỉnh sửa thuộc tính của một tài sản.|Bạn sắp chỉnh sửa thuộc tính của :asset_count tài sản.',
    'bulk_update_with_custom_field' => 'Lưu ý tài sản là :asset_model_count các loại model khác nhau.',
    'bulk_update_model_prefix' => 'Trên những model', 
    'bulk_update_custom_field_unique' => 'Đây là trường thông tin duy nhất và không thể chỉnh sửa hàng loạt.',
    'checkedout_to'		=> 'Checkout đến',
    'checkout_date'		=> 'Ngày Checkout',
    'checkin_date'		=> 'Ngày Checkin',
    'checkout_to'		=> 'Checkout đến',
    'cost'				=> 'Chi phí mua hàng',
    'create'			=> 'Tạo tài sản',
    'date'				=> 'Ngày mua',
    'depreciation'	    => 'Khấu hao',
    'depreciates_on'	=> 'Trích khấu hao',
    'default_location'	=> 'Vị trí mặc định',
    'default_location_phone' => 'Số điện thoại mặc định',
    'eol_date'			=> 'Ngày EOL',
    'eol_rate'			=> 'Tỷ lệ EOL',
    'expected_checkin'  => 'Ngày mong muốn Checkin',
    'expires'			=> 'Hết hạn',
    'fully_depreciated'	=> 'Khấu hao hết',
    'help_checkout'		=> 'Nếu bạn muốn cấp phát tài sản này ngay lập tức, lựa chọn "Sẵn sàng để cấp phát" từ danh sách tình trạng bên trên. ',
    'mac_address'		=> 'Địa chỉ MAC',
    'manufacturer'		=> 'Nhà sản xuất',
    'model'				=> 'Kiểu tài sản',
    'months'			=> 'tháng',
    'name'				=> 'Tên tài sản',
    'notes'				=> 'Ghi chú',
    'order'				=> 'Số đơn hàng',
    'qr'				=> 'Mã QR',
    'requestable'		=> 'Những người dùng có thể yêu cầu tài sản này',
    'redirect_to_all'   => 'Return to all :type',
    'redirect_to_type'   => 'Go to :type',
    'redirect_to_checked_out_to'   => 'Go to Checked Out to',
    'select_statustype'	=> 'Lựa chọn loại tình trạng',
    'serial'			=> 'Số Sê-ri',
    'status'			=> 'Tình trạng',
    'tag'				=> 'Thẻ tài sản',
    'update'			=> 'Cập nhật tài sản',
    'warranty'			=> 'Bảo hành',
        'warranty_expires'		=> 'Hết hạn bảo hành',
    'years'				=> 'năm',
    'asset_location' => 'Cập nhật vị trí tài sản',
    'asset_location_update_default_current' => 'Cập nhật vị trí tài sản mặc định VÀ vị trí thực tế',
    'asset_location_update_default' => 'Chỉ cập nhật vị trí tài sản mặc định',
    'asset_location_update_actual' => 'Chỉ cập nhật vị trí thực tế',
    'asset_not_deployable' => 'Trạng thái tài sản là không cho phép cấp phát. Tài sản này không thể bàn giao.',
    'asset_not_deployable_checkin' => 'That asset status is not deployable. Using this status label will checkin the asset.',
    'asset_deployable' => 'Trạng thái tài sản là được phép cấp phát. Tài sản này có thể bàn giao.',
    'processing_spinner' => 'Đang xử lý... (Quá trình này có thể mất một chút thời gian đối với các tệp lớn)',
    'optional_infos'  => 'Thông tin bổ sung',
    'order_details'   => 'Thông tin đơn hàng'
];
